@@ -103,18 +103,22 @@ def choose_mwc_site_url(default=None):
         except requests.exceptions.MissingSchema as e:
             click.echo(error(str(e)))
 
-def choose_course(options):
+def choose_course(options, default=None):
     """Asks the user which course they are part of"""
     if len(options) == 0:
         err = "There is a problem with the MWC site. Please ask a teacher for help."
         error(err)
         raise ValueError(err)
     elif len(options) == 1:
-        confirm(f"You are part of the course '{options[0]}'.")
+        if default and options[0] != default:
+            confirm(f"Changing your course from '{default}' to '{options[0]}'")
+        else:
+            confirm(f"You are part of the course '{options[0]}'.")
         return options[0]
     else:
-        return click.Choice(
+        return click.prompt(
             question("Choose your course:"), 
+            default=default,
             type=click.Choice(options),
         )  
 
@@ -327,6 +331,13 @@ class InstallHttpie(InstallPackage):
 class InstallScipy(InstallPackage):
     package_name = brew_name = apt_name = "scipy"
 
+    def is_complete(self):
+        try:
+            import scipy
+            return True
+        except ModuleNotFoundError:
+            return False
+
 class GHAuthentication(SetupTask):
     description = "Sign in to github"
     gh_auth_file = Path.home() / ".config/gh/hosts.yml"
